@@ -12,17 +12,18 @@
 extern "C" {
 #endif
 
-#ifdef myEnableJasper
-    #define kDCMvers "1Jan2017j" //JASPER for JPEG2000
-#else
-	#ifdef myDisableOpenJPEG
-    #define kDCMvers "1Jan2017" //no decompressor
-	#else
-    #define kDCMvers "1Jan2017o" //OPENJPEG for JPEG2000
-    #endif
-#endif
+ #ifdef myEnableJasper
+  #define kDCMsuf " (jasper build)"
+ #else
+  #ifdef myDisableOpenJPEG
+    #define kDCMsuf ""
+  #else
+    #define kDCMsuf " (openJPEG build)"
+  #endif
+ #endif
+ #define kDCMvers "v1.0.20170314" kDCMsuf
 
-static const int kMaxDTI4D = 4000; //#define kMaxDTIv  4000
+static const int kMaxDTI4D = 16000; //#define kMaxDTIv  4000
 #define kDICOMStr 40
 #define kMANUFACTURER_UNKNOWN  0
 #define kMANUFACTURER_SIEMENS  1
@@ -56,7 +57,7 @@ static const int kCompress50 = 3; //obsolete JPEG lossy
         long seriesNum;
         int xyzDim[5];//, xyzOri[4];
         int patientPositionNumPhilips, coilNum, echoNum, sliceOrient,numberOfDynamicScans, manufacturer, converted2NII, acquNum, imageNum, imageStart, imageBytes, bitsStored, bitsAllocated, samplesPerPixel,patientPositionSequentialRepeats,locationsInAcquisition, compressionScheme; //
-        float flipAngle, fieldStrength, TE, TR,intenScale,intenIntercept, gantryTilt, lastScanLoc, angulation[4];
+        float flipAngle, fieldStrength, TE, TR,intenScale,intenIntercept,intenScalePhilips, gantryTilt, lastScanLoc, angulation[4];
         float orient[7], patientPosition[4], patientPositionLast[4], xyzMM[4], stackOffcentre[4]; //patientPosition2nd[4],
         double dateTime, acquisitionTime, acquisitionDate;
         bool isXRay, isSlicesSpatiallySequentialPhilips, isNonImage, isValid, is3DAcq, isExplicitVR, isLittleEndian, isPlanarRGB, isSigned, isHasPhase,isHasMagnitude,isHasMixed, isFloat, isResampled;
@@ -69,14 +70,13 @@ static const int kCompress50 = 3; //obsolete JPEG lossy
     struct TDICOMdata readDICOMv(char * fname, int isVerbose, int compressFlag, struct TDTI4D *dti4D);
     struct TDICOMdata readDICOM(char * fname);
     struct TDICOMdata clear_dicom_data();
+    struct TDICOMdata  nii_readParRec (char * parname, int isVerbose, struct TDTI4D *dti4D);
     unsigned char * nii_flipY(unsigned char* bImg, struct nifti_1_header *h);
     unsigned char * nii_flipZ(unsigned char* bImg, struct nifti_1_header *h);
     unsigned char * nii_reorderSlices(unsigned char* bImg, struct nifti_1_header *h, struct TDTI4D *dti4D);
     void changeExt (char *file_name, const char* ext);
-    struct TDICOMdata  nii_readParRec (char * parname, int isVerbose, struct TDTI4D *dti4D);
     unsigned char * nii_planar2rgb(unsigned char* bImg, struct nifti_1_header *hdr, int isPlanar);
 	int isDICOMfile(const char * fname); //0=not DICOM, 1=DICOM, 2=NOTSURE(not part 10 compliant)
-
     int headerDcm2Nii2(struct TDICOMdata d, struct TDICOMdata d2, struct nifti_1_header *h);
     //unsigned char * nii_loadImgX(char* imgname, struct nifti_1_header *hdr, struct TDICOMdata dcm, bool iVaries);
     unsigned char * nii_loadImgXL(char* imgname, struct nifti_1_header *hdr, struct TDICOMdata dcm, bool iVaries, int compressFlag, int isVerbose);
